#!/bin/bash

# Situation: 
#  * we've booted with the 2.4 kernel, which can write to /root properly
#  * /dev/mtdblock/4 (old /nand1) is mounted as root
#  * /CMG-DCM-mk2x.tar.gz should exist
#  * /support should exist
#  * /dev/mtdblock/1 (old /boot) needs to be written
#  * /dev/mtdblock/2 (old /) needs to be written
#  * /dev/mtdblock/[34] need to be erased

echo "Beginning Platinum upgrade, stage 2..."

set -ex

# clean root and boot partition
/sbin/mkyaffs /dev/mtd/2

# upgrade root partition
mount -t yaffs /dev/mtdblock/2 /mnt
gunzip < /CMG-DCM-mk2x.tar.gz | tar -C /mnt -xp
sync

# copy across stored settings
mkdir -p /mnt/etc/ssh || true
cp /support/new-ssh/* /mnt/etc/ssh || true
mkdir -p /mnt/etc/conf.local || true
cp /support/new-ifcfg-eth0 /mnt/etc/conf.local/ifcfg-eth0
sync

# upgrade boot partition
/sbin/mkyaffs /dev/mtd/1 /usr/share/boot/boot.yaffs
sync

# tricky step: we want to erase the old /nand0 and /nand1 (currently root!) partitions
/sbin/mkyaffs /dev/mtd/3
/sbin/mkyaffs /dev/mtd/4

# this step could possibly fail, as we just destroyed the mounted root fs, but the 
# watchdog will reboot us in that case
LD_LIBRARY_PATH="/mnt/lib" /mnt/sbin/reboot -n
